@@ -24,8 +24,8 @@
 #include "qmmp_export.h"
 
 #define QMMP_VERSION_MAJOR 2
-#define QMMP_VERSION_MINOR 0
-#define QMMP_VERSION_PATCH 4
+#define QMMP_VERSION_MINOR 1
+#define QMMP_VERSION_PATCH 2
 #define QMMP_VERSION_STABLE 1
 
 #define QMMP_VERSION_INT (QMMP_VERSION_MAJOR<<16 | QMMP_VERSION_MINOR<<8 | QMMP_VERSION_PATCH)
@@ -138,11 +138,6 @@ public:
         CHAN_SIDE_RIGHT   = 0x80,   /*!< Side right channel */
         CHAN_LFE          = 0x100,  /*!< Low-frequency effects channel */
     };
-
-    /*!
-     * Returns the configuration file name, including the path.
-     */
-    static QString configFile();
     /*!
      * Returns the configuration directory path.
      */
@@ -151,6 +146,10 @@ public:
      * Overrides default configuration directory path.
      */
     static void setConfigDir(const QString &path);
+    /*!
+     * Returns the cache directory path.
+     */
+    static QString cacheDir();
     /*!
      * Returns %Qmmp library version.
      */
@@ -181,6 +180,11 @@ public:
      * Returns a directory location where persistent application data can be stored.
      */
     static QString dataPath();
+    /*!
+     * Returns a directory location where user writable application data can be stored
+     * (see XDG Base Directory specification).
+     */
+    static QString userDataPath();
 #ifdef Q_OS_WIN
     /*!
      * Returns \b true if portable mode is enabled. Otherwise returns \b false.
